@@ -35,12 +35,26 @@
 **
 **  RCS:
 **
-**	$Source: /afs/pitt.edu/usr12/dgm/work/IMAP_Proxy/src/RCS/main.c,v $
-**	$Id: main.c,v 1.27 2005/07/06 11:49:40 dgm Exp $
+**	$Source: /afs/andrew.cmu.edu/usr18/dave64/work/IMAP_Proxy/src/RCS/main.c,v $
+**	$Id: main.c,v 1.31 2006/10/03 12:13:09 dave64 Exp $
 **      
 **  Modification History:
 **
 **	$Log: main.c,v $
+**	Revision 1.31  2006/10/03 12:13:09  dave64
+**	Patch by Matt Selsky to log ssl peer verify at debug level instead
+**	of err level.
+**
+**	Revision 1.30  2006/04/13 12:39:15  dave64
+**	Patch by Ramiro Morales to prevent bad file descriptor error
+**	on startup.
+**
+**	Revision 1.29  2006/02/16 18:43:42  dave64
+**	Added IMAP_PROXY_VERSION string to startup log message.
+**
+**	Revision 1.28  2006/02/16 18:30:14  dave64
+**	Fixed string format bug (Debian DSA 852-1) found by Steve Kemp.
+**
 **	Revision 1.27  2005/07/06 11:49:40  dgm
 **	Add support for enable_admin_commands config option.
 **
@@ -157,9 +171,9 @@
 */
 
 
-static char *rcsId = "$Id: main.c,v 1.27 2005/07/06 11:49:40 dgm Exp $";
-static char *rcsSource = "$Source: /afs/pitt.edu/usr12/dgm/work/IMAP_Proxy/src/RCS/main.c,v $";
-static char *rcsAuthor = "$Author: dgm $";
+static char *rcsId = "$Id: main.c,v 1.31 2006/10/03 12:13:09 dave64 Exp $";
+static char *rcsSource = "$Source: /afs/andrew.cmu.edu/usr18/dave64/work/IMAP_Proxy/src/RCS/main.c,v $";
+static char *rcsAuthor = "$Author: dave64 $";
 
 #define _REENTRANT
 
@@ -615,7 +629,7 @@ int main( int argc, char *argv[] )
 	exit( 1 );
     }
 
-    syslog( LOG_INFO, "%s: Normal server startup.", fn );
+    syslog( LOG_INFO, "%s: imapproxy version %s normal server startup.", fn, IMAP_PROXY_VERSION );
 
     /*
      * Main server loop
@@ -849,7 +863,7 @@ static int ParseBannerAndCapability( char *DestBuf,
 	exit( 1 );
     }
     
-    sprintf( DestBuf, CP );
+    sprintf( DestBuf, "%s", CP );
     
     /*
      * initially assume that the server doesn't support UNSELECT.
@@ -977,7 +991,10 @@ static void SetBannerAndCapability( void )
 	    
 	    sleep( 15 );    /* IMAP server may not be started yet. */
 	}
-	break;  /* Success */
+	else
+	{
+	    break;  /* Success */
+	}
     }
     
     
@@ -1115,7 +1132,7 @@ static int verify_callback(int ok, X509_STORE_CTX * ctx)
     int     err;
     int     depth;
 
-    syslog(LOG_ERR,"Doing a peer verify");
+    syslog(LOG_DEBUG,"Doing a peer verify");
 
     err_cert = X509_STORE_CTX_get_current_cert(ctx);
     err = X509_STORE_CTX_get_error(ctx);
